elastic-apm -- Elastic APM agent for Python
===========================================

.. image:: https://apm-ci.elastic.co/buildStatus/icon?job=apm-agent-python%2Fapm-agent-python-mbp%2Fmain
    :target: https://apm-ci.elastic.co/job/apm-agent-python/job/apm-agent-python-mbp/
    :alt: Build Status

.. image:: https://img.shields.io/pypi/v/elastic-apm.svg?style=flat
    :target: https://pypi.python.org/pypi/elastic-apm/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/elastic-apm.svg?style=flat
    :target: https://pypi.python.org/pypi/elastic-apm/
    :alt: Supported Python versions


This is the official Python module for Elastic APM.

It provides full out-of-the-box support for many of the popular frameworks,
including Django, and Flask. Elastic APM is also easy to adapt for most
WSGI-compatible web applications via `custom integrations`_.

Your application doesn't live on the web? No problem! Elastic APM is easy to use in
any Python application.

Read the documentation_, including instructions on `running the tests locally`_.

If you're interested in contributing, `start here!`_

.. _documentation: https://www.elastic.co/guide/en/apm/agent/python/current/index.html
.. _`custom integrations`: https://www.elastic.co/blog/creating-custom-framework-integrations-with-the-elastic-apm-python-agent
.. _`running the tests locally`: https://www.elastic.co/guide/en/apm/agent/python/current/run-tests-locally.html
.. _`start here!`: https://github.com/elastic/apm-agent-python/blob/main/CONTRIBUTING.md

License
-------

BSD-3-Clause


Made with ♥️ and ☕️ by Elastic and our community.
